==> haskell-xml-hamlet-0.5.0.2-202-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xml-hamlet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xml-hamlet
version:              0.5.0.2
visibility:           public
id:                   xml-hamlet-0.5.0.2-9EDD52e9qRJpa7KP4qPzg
key:                  xml-hamlet-0.5.0.2-9EDD52e9qRJpa7KP4qPzg
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://www.yesodweb.com/
synopsis:             Hamlet-style quasiquoter for XML content
description:          Hamlet-style quasiquoter for XML content
category:             Text
abi:                  8998a58ba779fa2260a573351eed18cd
exposed:              True
exposed-modules:      Text.Hamlet.XML
hidden-modules:       Text.Hamlet.XMLParse
import-dirs:          /usr/lib/ghc-9.2.8/site-local/xml-hamlet-0.5.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/xml-hamlet-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xml-hamlet
hs-libraries:         HSxml-hamlet-0.5.0.2-9EDD52e9qRJpa7KP4qPzg
depends:
    base-4.16.4.0 containers-0.6.5.1 parsec-3.1.15.0
    shakespeare-2.1.0.1-2lgQsUoYeRe5970itwHhdo
    template-haskell-2.18.0.0 text-1.2.5.0
    xml-conduit-1.9.1.3-HbkbYL3ME9w6fRyCkvPCeI

haddock-interfaces:   /usr/share/doc/haskell-xml-hamlet/html/xml-hamlet.haddock
haddock-html:         /usr/share/doc/haskell-xml-hamlet/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-xml-hamlet-0.5.0.2-203-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-xml-hamlet.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 xml-hamlet
version:              0.5.0.2
visibility:           public
id:                   xml-hamlet-0.5.0.2-ewlgSCT7tpGotTi79CP4o
key:                  xml-hamlet-0.5.0.2-ewlgSCT7tpGotTi79CP4o
license:              BSD-3-Clause
maintainer:           michael@snoyman.com
author:               Michael Snoyman
homepage:             http://www.yesodweb.com/
synopsis:             Hamlet-style quasiquoter for XML content
description:          Hamlet-style quasiquoter for XML content
category:             Text
abi:                  2e3bb81028b27db2003675f814e88535
exposed:              True
exposed-modules:      Text.Hamlet.XML
hidden-modules:       Text.Hamlet.XMLParse
import-dirs:          /usr/lib/ghc-9.2.8/site-local/xml-hamlet-0.5.0.2
library-dirs:         /usr/lib/ghc-9.2.8/site-local/xml-hamlet-0.5.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xml-hamlet
hs-libraries:         HSxml-hamlet-0.5.0.2-ewlgSCT7tpGotTi79CP4o
depends:
    base-4.16.4.0 containers-0.6.5.1 parsec-3.1.15.0
    shakespeare-2.1.0.1-2lgQsUoYeRe5970itwHhdo
    template-haskell-2.18.0.0 text-1.2.5.0
    xml-conduit-1.9.1.3-Au4lwuO2FmbRiv813yqTY

haddock-interfaces:   /usr/share/doc/haskell-xml-hamlet/html/xml-hamlet.haddock
haddock-html:         /usr/share/doc/haskell-xml-hamlet/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
